/*
   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: LGPL-2.0-or-later
*/

#pragma once

#include <QObject>

class TemplateExtractHtmlElementFromMailTest : public QObject
{
    Q_OBJECT
public:
    explicit TemplateExtractHtmlElementFromMailTest(QObject *parent = nullptr);
    ~TemplateExtractHtmlElementFromMailTest() override = default;
private Q_SLOTS:
    void shouldHaveDefaultValue();
    void shouldExtractHtml_data();
    void shouldExtractHtml();
};

